package com.xinelu.manage.service.nursestationdepartment;


import com.xinelu.common.core.domain.AjaxResult;
import com.xinelu.manage.domain.nursestationdepartment.NurseStationDepartment;
import com.xinelu.manage.vo.nursestationdepartment.NurseStationDepartmentVO;

import java.util.List;

/**
 * 护理站部门信息Service接口
 *
 * @author zh
 * @date 2022-09-13
 */
public interface INurseStationDepartmentService {
    /**
     * 查询护理站部门信息
     *
     * @param id 护理站部门信息主键
     * @return 护理站部门信息
     */
    NurseStationDepartmentVO selectNurseStationDepartmentById(Long id);

    /**
     * 查询护理站部门信息列表
     *
     * @param nurseStationDepartment 护理站部门信息
     * @return 护理站部门信息集合
     */
    List<NurseStationDepartmentVO> selectNurseStationDepartmentList(NurseStationDepartmentVO nurseStationDepartment);

    /**
     * 新增护理站部门信息
     *
     * @param nurseStationDepartment 护理站部门信息
     * @return 结果
     */
    AjaxResult insertStationDepartmentList(List<NurseStationDepartment> nurseStationDepartment);

    /**
     * 修改护理站部门信息
     *
     * @param nurseStationDepartment 护理站部门信息
     * @return 结果
     */
    AjaxResult updateNurseStationDepartment(NurseStationDepartment nurseStationDepartment);

    /**
     * 批量删除护理站部门信息
     *
     * @param ids 需要删除的护理站部门信息主键集合
     * @return 结果
     */
    int deleteNurseStationDepartmentByIds(Long[] ids);
}